## 融资融券交易明细

接口：margin_detail

描述：获取沪深两市每日融资融券明细

限量：单次请求最大返回6000行数据，可根据日期循环

权限：2000积分可获得本接口权限，积分越高权限越大，具体参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（格式：YYYYMMDD，下同） |
| ts_code | str | N | TS代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| trade_date | str | 交易日期 |
| ts_code | str | TS股票代码 |
| name | str | 股票名称 （20190910后有数据） |
| rzye | float | 融资余额(元) |
| rqye | float | 融券余额(元) |
| rzmre | float | 融资买入额(元) |
| rqyl | float | 融券余量（股） |
| rzche | float | 融资偿还额(元) |
| rqchl | float | 融券偿还量(股) |
| rqmcl | float | 融券卖出量(股,份,手) |
| rzrqye | float | 融资融券余额(元) |

接口使用

```python
pro = ts.pro_api()

df = pro.margin_detail(trade_date='20180802')
```

或者

```python
df = pro.query('margin_detail', trade_date='20180802')
```

数据样例

```python
trade_date    ts_code          rzye        rqye        rzmre       rqyl  \
0     20180802  000001.SZ  4.430811e+09   8238210.0   78800436.0   921500.0   
```

说明

本报表基于证券公司报送的融资融券余额数据汇总生成，其中：

本日融资余额(元)=前日融资余额＋本日融资买入-本日融资偿还额

本日融券余量(股)=前日融券余量＋本日融券卖出量-本日融券买入量-本日现券偿还量

本日融券余额(元)=本日融券余量×本日收盘价

本日融资融券余额(元)=本日融资余额＋本日融券余额

单位说明：股（标的证券为股票）、份（标的证券为基金）、手（标的证券为债券）。

2014年9月22日起，“融资融券交易总量”数据包含调出标的证券名单的证券的融资融券余额。